Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func WithShutdown ¶
WithShutdown returns an enriched version of the original Context which will be cancelled when the user wants to shut down the program by sending SIGINT or SIGTERM. If the user sends the signal again before the program has finished shutting down then it will exit immediately with exit status 1.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.